==> haskell-hls-module-name-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-module-name-plugin-2.1.0.0-J9LN1gTFYdZ5SgzGSCp3Ua
key:                  hls-module-name-plugin-2.1.0.0-J9LN1gTFYdZ5SgzGSCp3Ua
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  de2a10c8c1f6854eb876e1031026c7ac
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.1.0.0-J9LN1gTFYdZ5SgzGSCp3Ua
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-module-name-plugin-2.2.0.0-5-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-module-name-plugin-2.2.0.0-3dQo6klzH8LKWqJ0aZAZD4
key:                  hls-module-name-plugin-2.2.0.0-3dQo6klzH8LKWqJ0aZAZD4
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  79876d80f4be84eacd952ef01e453631
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.2.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.2.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-module-name-plugin-2.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.2.0.0-3dQo6klzH8LKWqJ0aZAZD4
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH base-4.18.2.1 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    ghcide-2.2.0.0-3Yg9MkjnxcVIL3J9DYdUy
    hls-plugin-api-2.2.0.0-KgtR7fczL9LuWk9Dx0p1D
    lsp-2.2.0.0-8xJnLrvCaqxFP1VN2WNi9Q text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
